@@ -29,6 +29,7 @@
 
 #include <sys/stat.h>
 #include <glade/glade.h>
+#include <pi-util.h>
 #include "pilot.h"
 #include "util.h"
 #include "gnome-pilot-pdialog.h"
@@ -55,7 +56,6 @@ struct _GnomePilotPDialogPrivate
 
 	GtkWidget *pilot_name;
 	GtkWidget *pilot_basedir;
-	GtkWidget *pilot_sync_type;
 
 	GtkWidget *sync_dialog;
 };
@@ -145,6 +145,7 @@ init (GnomePilotPDialog *gppd)
 	}
 
  error:
+	;
 }
 
 
@@ -194,7 +195,6 @@ get_widgets (GnomePilotPDialog *gppd)
 	
 	priv->pilot_name = GW ("pilot_name_entry");
 	priv->pilot_basedir = GW ("pilot_basedir_entry");
-	priv->pilot_sync_type = GW ("sync_type_menu");
 	
 #undef GW
 	return (priv->dialog
@@ -203,8 +203,7 @@ get_widgets (GnomePilotPDialog *gppd)
 		&& priv->pilot_get
 		&& priv->pilot_send
 		&& priv->pilot_name
-		&& priv->pilot_basedir
-		&& priv->pilot_sync_type);
+		&& priv->pilot_basedir);
 }
 
 static void
@@ -218,7 +217,6 @@ map_widgets (GnomePilotPDialog *gppd)
 	gtk_object_set_data (GTK_OBJECT (gppd), "pilotid", priv->pilot_id);
 	gtk_object_set_data (GTK_OBJECT (gppd), "pilotname", priv->pilot_name);
 	gtk_object_set_data (GTK_OBJECT (gppd), "basedir", priv->pilot_basedir);
-	gtk_object_set_data (GTK_OBJECT (gppd), "sync_menu", priv->pilot_sync_type);
 }
 
 static void 
@@ -258,19 +256,18 @@ fill_widgets (GnomePilotPDialog *gppd)
 
 		gtk_entry_set_text (GTK_ENTRY (priv->pilot_name), priv->pilot->name);
 		gtk_entry_set_text (GTK_ENTRY (priv->pilot_basedir), priv->pilot->sync_options.basedir);
-
-		fill_synctype_menu (GTK_OPTION_MENU (priv->pilot_sync_type), priv->pilot->sync_options.default_sync_action);
 	}
 }
 
 gboolean
-gnome_pilot_pdialog_run_and_close (GnomePilotPDialog *gppd)
+gnome_pilot_pdialog_run_and_close (GnomePilotPDialog *gppd, GtkWindow *parent)
 {
 	GnomePilotPDialogPrivate *priv;
 	gint btn;
 	
 	priv = gppd->priv;
 	
+	gnome_dialog_set_parent (GNOME_DIALOG (priv->dialog), parent);
 	btn = gnome_dialog_run (GNOME_DIALOG (priv->dialog));
 	
 	if (btn == 0)
@@ -321,7 +318,9 @@ gppd_userinfo_requested (GnomePilotClient *gpc,
 
 	if (priv->pilot->pilot_username) 
 		g_free (priv->pilot->pilot_username);
-	priv->pilot->pilot_username = g_strdup (user->username);
+	if (!user->username || (convert_FromPilotChar ("UTF-8", user->username, strlen (user->username), &priv->pilot->pilot_username ) == -1)) {
+  		priv->pilot->pilot_username = g_strdup (user->username);
+	}
 
 	gtk_entry_set_text (GTK_ENTRY (priv->pilot_username), priv->pilot->pilot_username);
 	g_snprintf (buf, sizeof (buf), "%d", priv->pilot->pilot_id);
@@ -379,6 +378,8 @@ gppd_sync_dialog (GnomePilotPDialog *gppd,
 	priv->sync_dialog = gnome_message_box_new (txt, GNOME_MESSAGE_BOX_GENERIC, GNOME_STOCK_BUTTON_CANCEL, NULL);
 	g_free (txt);
 
+	gnome_dialog_set_parent (GNOME_DIALOG (priv->sync_dialog), GTK_WINDOW (priv->dialog));
+
 	gnome_dialog_button_connect (GNOME_DIALOG (priv->sync_dialog), 0, gppd_cancel_sync, gppd);
 	gnome_dialog_run_and_close (GNOME_DIALOG (priv->sync_dialog));
 }
@@ -406,7 +407,7 @@ gppd_pilot_get (GtkWidget *widget, gpointer user_data)
 							&priv->handle2) == GPILOTD_OK) {
 			gppd_sync_dialog (gppd, dev);
 		} else {
-			error_dialog (_("The request to get pilot id failed"));
+			error_dialog (GTK_WINDOW (priv->dialog), _("The request to get pilot id failed"));
 		}
 	}
 }
@@ -429,8 +430,9 @@ gppd_pilot_send (GtkWidget *widget, gpointer user_data)
 		read_pilot_config (GTK_OBJECT (gppd), pilot);
 
 		user.userID = pilot->pilot_id;
-		user.username = g_strdup (pilot->pilot_username);
-
+		if (! pilot->pilot_username || (convert_ToPilotChar ("UTF-8", pilot->pilot_username,strlen(pilot->pilot_username),&user.username) == -1)) {
+			user.username = g_strdup (pilot->pilot_username);
+		}
 		if (gnome_pilot_client_set_user_info (priv->gpc, 
 						      dev->name, 
 						      user, 
@@ -445,7 +447,7 @@ gppd_pilot_send (GtkWidget *widget, gpointer user_data)
 							&priv->handle2) == GPILOTD_OK) {
 			gppd_sync_dialog (gppd, dev);
 		} else {
-			error_dialog (_("The request to set pilot id failed"));
+			error_dialog (GTK_WINDOW (priv->dialog), _("The request to set pilot id failed"));
 		}
 		gpilot_pilot_free (pilot);	
 	}
