@@ -59,14 +59,22 @@ monitor_pilots (GnomePilotClient *gpc, PilotState * state)
 	}
 }
 
+static void
+response_cb (GtkDialog *dialog, gint response_id)
+{
+	if (response_id == GTK_RESPONSE_HELP) {
+		gnome_help_display_desktop (NULL, "gnome-pilot", "gnome-pilot.xml", "conftool-pilots", NULL);
+	} else {
+		gtk_main_quit ();
+	}
+}
+
 int
 main (int argc, char *argv[])
 {
 	GnomePilotClient *gpc = NULL;
 	PilotState *state = NULL;
 	GnomePilotCapplet *gpcap = NULL;
-	GtkWidget *gpcc = NULL;
-	GtkWidget *capplet = NULL;
 	gboolean druid_on = FALSE, druid_prog = FALSE;
 
 	struct poptOption options[] = {
@@ -78,6 +86,7 @@ main (int argc, char *argv[])
 	
 	bindtextdomain (PACKAGE, GNOMELOCALEDIR);
 	textdomain (PACKAGE);
+	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	
 	if (argc > 1 && strcmp (argv[1], "--druid") == 0) {
 		gnome_init_with_popt_table ("gpilot-control-applet",
@@ -102,7 +111,7 @@ main (int argc, char *argv[])
 	
 	/* put all code to set things up in here */
 	if (loadPilotState (&state) < 0) {
-		error_dialog (_("Error loading pilot state, aborting"));
+		error_dialog (NULL, _("Error loading pilot state, aborting"));
 		g_error (_("Error loading pilot state, aborting"));
 		return -1;
 	}
@@ -110,7 +119,7 @@ main (int argc, char *argv[])
 	gpc = GNOME_PILOT_CLIENT (gnome_pilot_client_new ());
 
 	if (gnome_pilot_client_connect_to_daemon (gpc) != GPILOTD_OK) {
-		error_dialog (_("Cannot connect to the GnomePilot Daemon"));
+		error_dialog (NULL,_("Cannot connect to the GnomePilot Daemon"));
 		g_error (_("Cannot connect to the GnomePilot Daemon"));
 		return -1;
 	}
@@ -120,33 +129,35 @@ main (int argc, char *argv[])
 		GtkObject *druid;
 		
 		if (state->pilots!= NULL || state->devices!= NULL) {
-			error_dialog (_("Cannot run druid if pilots or cradles already configured"));
+			error_dialog (NULL, _("Cannot run druid if pilots or cradles already configured"));
 			return -1;
 		}
 
 		druid = gnome_pilot_druid_new (gpc);
 		gnome_pilot_druid_run_and_close (GNOME_PILOT_DRUID (druid));
 	} else {
+		gboolean druid_finished = TRUE;
+		
 		gpcap = gnome_pilot_capplet_new (gpc);
 
 		/* quit when the Close button is clicked on our dialog */
-		gtk_signal_connect (GTK_OBJECT (gpcap), "response", GTK_SIGNAL_FUNC (gtk_main_quit), NULL);
-
-		gtk_widget_show (GTK_WIDGET (gpcap));
+		g_signal_connect (G_OBJECT (gpcap), "response", G_CALLBACK (response_cb), NULL);
 
 		/* popup the druid if nothing is configured - assume this is the first time */
 		if (state->pilots == NULL && state->devices == NULL) {
 			GtkObject *druid;
 			
 			druid = gnome_pilot_druid_new (gpc);
-			gnome_pilot_druid_run_and_close (GNOME_PILOT_DRUID (druid));
+			druid_finished = gnome_pilot_druid_run_and_close (GNOME_PILOT_DRUID (druid));
 
 			if (gpcap != NULL)
 				gnome_pilot_capplet_update (GNOME_PILOT_CAPPLET (gpcap));
 		}
 
-		/* done setting up, now run main loop */
-		gtk_main();
+		if (druid_finished) {
+			gtk_widget_show (GTK_WIDGET (gpcap));
+			gtk_main ();
+		}		
 	}
 	freePilotState (state);
 
