@@ -21,7 +21,7 @@
  *          Robert Mibus
  */
 
-/* $Id: backup_conduit.c,v 1.45 2003/01/26 02:19:51 toshok Exp $ */
+/* $Id: backup_conduit.c,v 1.47 2003/03/18 15:12:25 jpr Exp $ */
 
 #include <glib.h>
 #include <gnome.h>
@@ -113,7 +113,8 @@ load_configuration(GnomePilotConduit *conduit,
 	if ((*c)->backup_dir == NULL) {
 		if (conduit != NULL && GNOME_IS_PILOT_CONDUIT (conduit)) {
 			(*c)->backup_dir = g_strdup (gnome_pilot_conduit_get_base_dir (conduit));
-		} else {
+		} 
+		if ((*c)->backup_dir == NULL) {
 			(*c)->backup_dir = g_strdup (g_get_home_dir ());
 		}
 	}
@@ -138,18 +139,20 @@ load_configuration(GnomePilotConduit *conduit,
 	if((*c)->backup_dir != NULL) {
 		(*c)->files_in_backup = NULL;
 		dir = opendir ((*c)->backup_dir);
-		while ((entry = readdir (dir))) {
-			if (entry->d_name) {
-				if (strlen(entry->d_name) > 4) { /* ignores ., .., 0-9999 */
-					temp_name = g_strdup_printf ("%s/%s", 
-								     ((*c)->backup_dir), 
-								     entry->d_name);
-					(*c)->files_in_backup = g_list_prepend ((*c)->files_in_backup, 
-										temp_name);
+		if (dir) {
+			while ((entry = readdir (dir))) {
+				if (entry->d_name) {
+					if (strlen(entry->d_name) > 4) { /* ignores ., .., 0-9999 */
+						temp_name = g_strdup_printf ("%s/%s", 
+									     ((*c)->backup_dir), 
+									     entry->d_name);
+						(*c)->files_in_backup = g_list_prepend ((*c)->files_in_backup, 
+											temp_name);
+					}
 				}
 			}
+			closedir (dir);
 		}
-		closedir (dir);
 	}
 
 	(*c)->pilotId = pilot->pilot_id;
@@ -401,14 +404,13 @@ gnome_real_pilot_conduit_backup_backup (GnomePilotConduitBackup *conduit,
 		}
 	}
 
-	if (cfg->backup_dir == NULL) {
-		g_warning("backup conduit has no backupdir");
+	if (!g_file_test (cfg->backup_dir, G_FILE_TEST_IS_DIR | G_FILE_TEST_EXISTS)) {
+		g_warning("backup conduit has no usable backupdir");
 		gnome_pilot_conduit_send_error(GNOME_PILOT_CONDUIT(conduit),
-					       "No backup directory specified");
+					       "No usable backup directory specified");
 		result = -1;
 		goto exit;
-	} 
-
+	}
 
 	name = gnome_pilot_conduit_backup_create_name (conduit, dbinfo, cfg);
 	
@@ -565,17 +567,22 @@ gnome_real_pilot_conduit_backup_backup (GnomePilotConduitBackup *conduit,
 		gnome_pilot_conduit_send_progress (GNOME_PILOT_CONDUIT (conduit),
 						   entries,
 						   index);
-	} while (keep_reading && index < entries);				  
+	} while (keep_reading && index < entries);
 
+	g_free (buffer);
+		
+	if (pi_file_close (f) < 0) {
+		g_warning("backup conduit can't write file");
+		gnome_pilot_conduit_send_error(GNOME_PILOT_CONDUIT(conduit),
+					       "Unable to write file to backup directory specified");
+		result = -1;
+		goto db_close;
+	}
+	
 	g_message ("Wrote %d of %d %s, which is %s",
 		   wrote, entries, PI_DBINFO (dbinfo)->flags & dlpDBFlagResource ? "resources" : "records",
 		   wrote == entries ? "good" : "BAD");
 
-	g_free (buffer);
-		
-	//dlp_ResetSyncFlags (dbinfo->pilot_socket, dbinfo->db_handle); 		
-
-	pi_file_close (f);
 	times.actime = PI_DBINFO (dbinfo)->createDate;
 	times.modtime = PI_DBINFO (dbinfo)->modifyDate;
 	utime (name, &times);
