@@ -51,7 +51,7 @@ static void
 gpilotd_request_completed (GnomePilotClient *gpc, gchar *pilot_id, gint handle, gpointer data)
 {
 	g_message ("%s completed %d", pilot_id, handle);
-	handles = g_slist_remove (handles,(gpointer)handle);
+	handles = g_slist_remove (handles,GINT_TO_POINTER(handle));
 	if (handles == NULL)
 		gnome_dialog_close (GNOME_DIALOG (dialog));
 }
@@ -62,7 +62,7 @@ cancel_install (GnomeDialog *w, GSList *list)
 	GSList *e;
 
 	for (e=list;e;e = g_slist_next (e)) {
-		gnome_pilot_client_remove_request (gpc,(gint)e->data);  
+		gnome_pilot_client_remove_request (gpc,GPOINTER_TO_INT(e->data));  
 	}
 	g_slist_free (list);
 
@@ -94,6 +94,7 @@ main (int argc, char *argv[])
         
 	bindtextdomain (PACKAGE, GNOMELOCALEDIR);
 	textdomain (PACKAGE);
+	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 
 	if (argc<2) {
 		g_message ("usage : %s [--now|--later] [FILE]", argv[0]);
@@ -104,6 +105,8 @@ main (int argc, char *argv[])
 				    argc, argv, options, 0, &pctx);
 	
 	gpc = GNOME_PILOT_CLIENT (gnome_pilot_client_new ());
+	gtk_object_ref (GTK_OBJECT (gpc));
+	gtk_object_sink (GTK_OBJECT (gpc));
 	gtk_signal_connect (GTK_OBJECT (gpc),"completed_request", (GtkSignalFunc)gpilotd_request_completed, NULL);
 	gnome_pilot_client_connect_to_daemon (gpc);
 
@@ -136,7 +139,7 @@ main (int argc, char *argv[])
 						       0,
 						       &handle);
 		if (err == GPILOTD_OK) {
-			handles = g_slist_prepend (handles,(gpointer)handle);
+			handles = g_slist_prepend (handles,GINT_TO_POINTER(handle));
 			notfailed = g_slist_prepend (notfailed, args[i]);
 		} else {
 			failed = g_slist_prepend (failed, args[i]);
@@ -218,9 +221,7 @@ main (int argc, char *argv[])
 		g_free (message);
 	}
 
-	/* gpilotd_shutdown (); */
-
-	bonobo_object_unref (BONOBO_OBJECT (gpc));
+	gtk_object_unref (GTK_OBJECT (gpc));
 
 	return 0;
 }
