@@ -23,9 +23,10 @@
  */
 
 #include <config.h>
-#include <stdlib.h>
 #include <time.h>
 #include <unistd.h>
+#include <stdlib.h>
+#include <stdio.h>
 #include "gnome-pilot-structures.h"
 #include "gpilot-gui.h"
 #include <libgnome/libgnome.h>
@@ -34,6 +35,7 @@
 #include <sys/stat.h>
 #include <string.h>
 #include <fcntl.h>
+#include <signal.h>
 
 /* From pi-csd */
 #include <signal.h>
@@ -89,8 +91,8 @@ GPilotContext *gpilot_context_new (void)
 #endif
 
 	/* get the id.  Does anyone know the valid range for this? */
-	srandom (time (NULL));
-	id = 1 + ((guint) 1000000.0*random ());
+	srand (time (NULL));
+	id = 1 + ((guint) 1000000.0*rand ());
 	gnome_config_push_prefix ("/gnome-pilot.d/gpilotd/General/");
 	str = g_strdup_printf ("sync_PC_Id=%d", id);
 	retval->sync_PC_Id=gnome_config_get_int (str);
@@ -180,7 +182,7 @@ gpilot_hdb_uucp_lock (GPilotDevice *device)
 	
 	device->lock_file = g_new0 (gchar, 128);
 
-	snprintf (device->lock_file, 127, "%s/LCK..%s", LOCK_DIR, dev);
+	g_snprintf (device->lock_file, 127, "%s/LCK..%s", LOCK_DIR, dev);
 
 	while ((fd = open (device->lock_file, O_EXCL | O_CREAT | O_RDWR, 0644)) < 0) {
 		if (errno != EEXIST) {
@@ -391,9 +393,11 @@ static void
 fetch_host (char *hostname, int hostlen, struct in_addr *address,
 	   struct in_addr *mask)
 {
+#if defined (SIOCGIFCONF) && defined (SIOCGIFFLAGS)
 	int s, n, i;
 	struct ifconf ifc;
 	struct ifreq *ifr, ifreqaddr, ifreqmask;
+#endif
 	struct hostent *hent;
 
 #ifdef HAVE_GETHOSTNAME
@@ -547,15 +551,7 @@ gpilot_network_device_init (GPilotDevice *device)
 
 
 /*   int sockfd;	this is device->fd */
-	struct sockaddr_in serv_addr, cli_addr;
-	int clilen;
-	char mesg[1026];
-	fd_set rset;
-	int n;
-	struct in_addr raddress;
-
-	extern char *optarg;
-	extern int optind;
+	struct sockaddr_in serv_addr;
 
 	struct hostent *hent;
 /*   int quiet = 0;		It's Always quiet here */
@@ -667,6 +663,7 @@ gpilot_device_init (GPilotDevice *device)
 #endif /* WITH_NETWORK */
 	} else {
 		g_warning (_("Unknown device type"));
+		result = -1;
 	}
 
 	return result;
@@ -855,7 +852,6 @@ void
 gpilot_pilot_init (GPilotPilot *pilot, 
 		   gint i)
 {
-	gchar *tmp_str;
 	gchar *prefix;
 
 	/* set up stuff  */
@@ -876,9 +872,6 @@ gpilot_pilot_init (GPilotPilot *pilot,
 	pilot->romversion = gnome_config_get_int ("romversion");
 	pilot->number=i;
 	pilot->trusted_users=NULL;
-	tmp_str = gnome_config_get_string("default_sync_action=synchronize");
-	pilot->sync_options.default_sync_action = gnome_pilot_conduit_sync_type_str_to_int(tmp_str);
-	g_free (tmp_str);
 	pilot->sync_options.basedir = gnome_config_get_string("basedir");
 
 	gnome_config_pop_prefix ();
