@@ -48,6 +48,9 @@
 #include <stdio.h>
 #include <fcntl.h>
 
+#include <libxml/xmlmemory.h>
+#include <libxml/entities.h>
+
 #include <libgnome/libgnome.h>
 
 #include <pi-source.h>
@@ -64,6 +67,7 @@
 
 /* Set to true when the config should be reloaded */
 gboolean reread_config;
+guint visor_timeout_id = -1;
 
 gint device_equal_by_io (GPilotDevice *,GIOChannel *);
 gboolean device_in (GIOChannel *,
@@ -479,69 +483,18 @@ do_sync (int pfd,
 	   restores etc. If this returns True, continue with normal conduit running,
 	   if False, don't proceed */
 	if (gpilot_initial_synchronize_operations (pfd,
-						  &stamp,
-						  pu,
-						  conduit_list,
-						  backup_conduit_list,
-						  file_conduit_list,
-						  device,
-						  context)) {
-
-		/* FIXME: We need to actually pass a different structure to these
-		   functions containing the pu item and the pilot pointer so that
-		   we can store the lastSyncPC and assorted fields in
-		   ~/.gnome_private/gnome-pilot.d/gpilotd. We will also need some
-		   lock mechanism when we start forking for that file :)*/
-		switch (pilot->sync_options.default_sync_action) {
-		case GnomePilotConduitSyncTypeSynchronize:
-			g_message (_("Synchronizing..."));
-			gpilot_synchronize (pfd,&stamp,pu,
-					   conduit_list,
-					   backup_conduit_list,
-					   file_conduit_list,
-					   context);
-			break;
-		case GnomePilotConduitSyncTypeCopyToPilot:
-			g_message (_("Copying to pilot..."));
-			gpilot_copy_to_pilot (pfd,&stamp,pu,
-					     conduit_list,
-					     backup_conduit_list,
-					     file_conduit_list,
-					     context);
-			break;
-		case GnomePilotConduitSyncTypeCopyFromPilot:
-			g_message (_("Copying from pilot..."));
-			gpilot_copy_from_pilot (pfd,&stamp,pu,
-					       conduit_list,
-					       backup_conduit_list,
-					       context);
-			break;
-		case GnomePilotConduitSyncTypeMergeToPilot:
-			g_message (_("Merging to pilot..."));
-			gpilot_merge_to_pilot (pfd,&stamp,pu,
-					      conduit_list,
-					      backup_conduit_list,
-					      file_conduit_list,
-					      context);
-			break;
-		case GnomePilotConduitSyncTypeMergeFromPilot:
-			g_message (_("Merging from pilot..."));
-			gpilot_merge_from_pilot (pfd,&stamp,pu,
-						conduit_list,
-						backup_conduit_list,
-						context);
-			break;
-		case GnomePilotConduitSyncTypeNotSet:
-		case GnomePilotConduitSyncTypeCustom:
-		default:
-			g_message (_("Using conduit settings for sync..."));
-			gpilot_sync_default (pfd,&stamp,pu,
-					    conduit_list,
-					    backup_conduit_list,
-					    file_conduit_list,
-					    context);
-			break;
-		}
+						   &stamp,
+						   pu,
+						   conduit_list,
+						   backup_conduit_list,
+						   file_conduit_list,
+						   device,
+						   context)) {
+		gpilot_sync_default (pfd,&stamp,pu,
+				     conduit_list,
+				     backup_conduit_list,
+				     file_conduit_list,
+				     context);
 		g_message (_("Synchronization ended")); 
 		gpilot_add_log_entry (pfd,"Synchronization completed");
 	} else {
@@ -626,9 +579,11 @@ static gboolean
 sync_device (GPilotDevice *device, GPilotContext *context)
 {
 	GPilotPilot *pilot;
+	
 	int pfd;
 	int connect_error;
 	struct PilotUser pu;
+	struct SysInfo ps;
 
 	g_assert (context != NULL);
 	g_return_val_if_fail (device != NULL, FALSE);
@@ -637,8 +592,13 @@ sync_device (GPilotDevice *device, GPilotContext *context)
 	pfd = pilot_connect (device,&connect_error);
 
 	if (!connect_error) {
+               /* connect succeeded, try to read the systeminfo */
+               if (dlp_ReadSysInfo (pfd, &ps) < 0) {
+                       /* no ? drop connection then */
+                       g_warning (_("An error occured while getting the pilot's system data"));
+
 		/* connect succeeded, try to read the userinfo */
-		if (dlp_ReadUserInfo (pfd,&pu) < 0) {
+		} else if (dlp_ReadUserInfo (pfd,&pu) < 0) {
 			/* no ? drop connection then */
 			g_warning (_("An error occured while getting the pilot's user data"));
 		} else {
@@ -830,23 +790,85 @@ network_device_err (GIOChannel *io_channel,
 
 #ifdef WITH_USB_VISOR
 #ifdef linux
-static const char *product_names[] =
-{
-	"Handspring Visor",
-	"Handspring Treo",
-	"Palm Handheld",
-	NULL
-};
+static GPtrArray *vendor_product_ids = NULL;
+static GArray *product_net = NULL;
 
+static void
+load_devices_xml (void) 
+{
+	xmlDoc *doc = NULL;
+	xmlNode *root, *node;
+	char *filename;
+	
+	if (vendor_product_ids)
+		return;
+	
+	vendor_product_ids = g_ptr_array_new ();
+	product_net = g_array_new (FALSE, FALSE, sizeof (gboolean));
+
+	filename = g_build_filename (DEVICE_XML_DIR, "devices.xml", NULL);
+	doc = xmlParseFile (filename);
+	g_free (filename);
+		
+	if (!doc) {
+		g_warning ("Unable to read device file at %s", filename);
+		
+		return;
+	}
+
+	root = xmlDocGetRootElement (doc);
+	if (!root->name || strcmp (root->name, "device-list"))
+		goto fail;
+	
+	for (node = root->children; node; node = node->next) {
+		xmlChar *vendor, *product, *net;
+		gboolean use_net;
+		
+		if (node->type != XML_ELEMENT_NODE)
+			continue;
+
+		if (!node->name || strcmp (node->name, "device")) {
+			g_warning ("Invalid sub node %s", node->name != NULL ? (char *) node->name : "");
+
+			continue;
+		}
+		
+		vendor = xmlGetProp (node, "vendor_id");
+		product = xmlGetProp (node, "product_id");
+
+		if (!vendor || !product) {
+			g_warning ("No vendor or product id");
+
+			continue;
+		}
+		
+		g_message ("Found %s, %s", vendor, product);
+		g_ptr_array_add (vendor_product_ids, g_strdup_printf ("Vendor=%s ProdID=%s", vendor, product));
+
+		xmlFree (vendor);
+		xmlFree (product);
+		
+		net = xmlGetProp (node, "use_net");
+		use_net = !net || strcmp (net, "false");
+		
+		g_message ("Using net %s", use_net ? "TRUE" : "FALSE");
+		g_array_append_val (product_net, use_net);
+
+		xmlFree (net);
+	}
+
+ fail:
+	xmlFreeDoc (doc);
+}
 
 static gboolean 
-visor_devices_in (GIOChannel *io_channel,
-		 GIOCondition condition,
-		 GPilotContext *context) {
+visor_devices_timeout (gpointer data) 
+{
+	GPilotContext *context = data;
 	GPilotDevice *device;
 	GList *l;
 	int i;
-	gboolean visor_exists = FALSE;
+	gboolean visor_exists = FALSE, visor_net = TRUE;
 	char line[256]; /* this is more than enough to fit any line from 
 			 * /proc/bus/usb/devices */
 
@@ -854,23 +876,29 @@ visor_devices_in (GIOChannel *io_channel,
 
 	g_assert (context != NULL);
 
-	sleep (2);	
-
 	if (context->paused) 
 		return FALSE;
 
-	/* Check /proc/bus/usb/devices for a visor */
+	load_devices_xml ();
+	
+	/* Check /proc/bus/usb/devices for a usb device */
 	f = fopen ("/proc/bus/usb/devices", "r");
+	if (!f)
+		f = fopen ("/proc/bus/usb/devices_please-use-sysfs-instead", "r");
+	if (!f)
+		return TRUE;
 	
 	while (fgets (line, 255, f) != NULL && !visor_exists) {
-		if (line[0] != 'S')
+		if (line[0] != 'P')
 			continue;
 		
-		for (i = 0; product_names[i] != NULL; i++) {
-			if (!strncmp (line + strlen ("S:  Product="), 
-				      product_names[i], 
-				      strlen (product_names[i])))
+		for (i = 0; i < vendor_product_ids->len; i++) {
+			if (!g_strncasecmp (line + strlen ("P:  "), 
+				      vendor_product_ids->pdata[i], 
+				      strlen (vendor_product_ids->pdata[i]))) {
 				visor_exists = TRUE;
+				visor_net = g_array_index (product_net, gboolean, i);
+			}
 		}
 	}
 	
@@ -881,10 +909,16 @@ visor_devices_in (GIOChannel *io_channel,
 		while (l) {
 			device = l->data;
 			if (device->type == PILOT_DEVICE_USB_VISOR) {
+				if (!visor_net)
+					device->type = PILOT_DEVICE_SERIAL;
+
 				/* just try to synch.  Until I can talk to 
 				 * the kernel guys this is the best way to 
                                  * go. */
 				sync_device (device, context);
+
+				if (!visor_net)
+					device->type = PILOT_DEVICE_USB_VISOR;
 			}
 			l = l->next;
 		}
@@ -893,24 +927,12 @@ visor_devices_in (GIOChannel *io_channel,
 	return TRUE;
 }
 
-static gboolean 
-visor_devices_err (GIOChannel *io_channel,
-	   GIOCondition condition,
-	   GPilotContext *context) 
+#endif
+#endif
+
+void monitor_channel (GPilotDevice *dev,GPilotContext *context) 
 {
 	g_assert (context != NULL);
-
-	gpilot_gui_warning_dialog ("Read error on /proc/bus/usb/devices"); 
-	g_warning ("Read error on /proc/bus/usb/devices");
-
-	return FALSE;
-}
-
-#endif
-#endif
-
-void monitor_channel (GPilotDevice *dev,GPilotContext *context) {
-	g_assert (context != NULL);
 	
 	if (dev->type == PILOT_DEVICE_SERIAL
 	    || dev->type == PILOT_DEVICE_IRDA) {
@@ -941,25 +963,8 @@ void monitor_channel (GPilotDevice *dev,GPilotContext *context) {
 		/* We want to watch the /proc/bus/usb/devices file once 
 		 * per context, and then check all devices each time it is
 		 * woken up. */
-		if (context->visor_fd == -1) {
-			context->visor_fd = open ("/proc/bus/usb/devices",
-						  O_RDONLY);
-			if (context->visor_fd == -1) {
-				g_warning ("Could not open /proc/bus/usb/devices - make sure you have the usbdevfs properly configured and mounted.");
-				return;
-			}
-			context->visor_io = 
-				g_io_channel_unix_new (context->visor_fd);
-			context->visor_in_handle = 
-				g_io_add_watch (context->visor_io,
-						G_IO_IN,
-						(GIOFunc)visor_devices_in,
-						(gpointer)context);
-			context->visor_err_handle = 
-				g_io_add_watch (context->visor_io,
-						G_IO_ERR|G_IO_PRI|G_IO_HUP|G_IO_NVAL,
-						(GIOFunc)visor_devices_err,
-						(gpointer)context);
+		if (visor_timeout_id == -1) {
+			visor_timeout_id = g_timeout_add (2000, visor_devices_timeout, context);
 		}
 #else /* linux*/
 		g_assert_not_reached ();
@@ -1127,6 +1132,7 @@ main (int argc, char *argv[])
 
 	bindtextdomain (PACKAGE, GNOMELOCALEDIR);
 	textdomain (PACKAGE);
+	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 
 	/*g_log_set_always_fatal (G_LOG_LEVEL_ERROR |
 				G_LOG_LEVEL_CRITICAL |
