@@ -1,5 +1,5 @@
 /* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- *//* 
- * Copyright (C) 1998-2000 Free Software Foundation
+ * Copyright (C) 1998-2001 Free Software Foundation
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -68,13 +68,14 @@ typedef struct {
 	struct PilotUser *pu;
 	int pilot_socket;
         GList *conduit_list;
+	GList *file_conduit_list;
         GnomePilotSyncStamp *syncstamp;
 } GnomePilotInstallCarrier;
 
 typedef gint (*iterate_func)(GnomePilotConduitStandard *, GnomePilotDBInfo *);
 
 /* Prototypes */
-static void unload_foreach (GnomePilotConduit *conduit, gpointer unused);
+static void gpilot_unload_conduit_foreach (GnomePilotConduit *conduit, gpointer unused);
 static gint find_matching_conduit_compare_func (GnomePilotConduit *a,
 						GnomePilotDBInfo *b);
 static GnomePilotConduit *find_matching_conduit (GList *conlist, GnomePilotDBInfo *dbinfo);
@@ -134,58 +135,79 @@ static gint
 find_matching_conduit_compare_func_name (GnomePilotConduit *conduit,
 					gchar *name) 
 {
-  if (GNOME_IS_PILOT_CONDUIT_STANDARD (conduit)) {
-    if (strcmp (gnome_pilot_conduit_standard_get_db_name (GNOME_PILOT_CONDUIT_STANDARD (conduit)),
-	      name)==0) {
-      return 0;
-    }
-  }
-  return -1;
+	if (GNOME_IS_PILOT_CONDUIT (conduit)) {
+		if (strcmp (gnome_pilot_conduit_get_name (conduit),
+			    name)==0) {
+			return 0;
+		}
+	}
+	return -1;
 }
 
 static GnomePilotConduit*
 find_matching_conduit_name (GList *conlist, gchar *name)
 {
-  GList *elem;
-  elem=g_list_find_custom (conlist, name,
-			  (GCompareFunc)find_matching_conduit_compare_func_name);
-  if (elem)
-    return GNOME_PILOT_CONDUIT (elem->data);
-  else
-    return NULL;
+	GList *elem;
+	elem=g_list_find_custom (conlist, name,
+				 (GCompareFunc)find_matching_conduit_compare_func_name);
+	if (elem)
+		return GNOME_PILOT_CONDUIT (elem->data);
+	else
+		return NULL;
 }
 
 /**************************************************************************/
 /* Here comes conduit signal handler, used to call methods from 
    orbit_daemon_glue                                                      */
 
+typedef struct {
+	GnomePilotInstallCarrier *carrier;
+	GnomePilotConduitFile *file_conduit;
+	gchar *pilot_name;
+} GnomePilotBackupFuncCarrier;
+
+static gint
+gnome_pilot_conduit_backup_func (gchar *filename,
+				 gint db,
+				 gint total_dbs,
+				 GnomePilotBackupFuncCarrier *carrier) {
+	orbed_notify_overall_progress (carrier->pilot_name, db, total_dbs);
+	
+	g_message ("gnome_pilot_conduit_backup_func (%s)", filename);
+
+	return gnome_pilot_conduit_file_install_db (carrier->file_conduit,
+						    carrier->carrier->pilot_socket,
+						    filename,
+						    FALSE);
+}
+
 static void 
 conduit_progress_callback (GnomePilotConduit *conduit, 
-			  gint total,
-			  gint current,
-			  gchar *pilot_id) {
-	orbed_notify_conduit_progress (pilot_id,
-				      conduit,
-				      current,
-				      total);
+			   gint total,
+			   gint current,
+			   gpointer pilot_id) {
+	orbed_notify_conduit_progress ((gchar*)pilot_id,
+				       conduit,
+				       current,
+				       total);
 }
 
 static void 
 conduit_message_callback (GnomePilotConduit *conduit, 
-			 gchar *message,
-			 gchar *pilot_id) {
-	orbed_notify_conduit_message (pilot_id,
-				     conduit,
-				     message);
+			  gchar *message,
+			  gpointer pilot_id) {
+	orbed_notify_conduit_message ((gchar*)pilot_id,
+				      conduit,
+				      message);
 }
 
 static void 
 conduit_error_callback (GnomePilotConduit *conduit, 
-		       gchar *message,
-			 gchar *pilot_id) {
-	orbed_notify_conduit_error (pilot_id,
-				   conduit,
-				   message);
+			gchar *message,
+			gpointer pilot_id) {
+	orbed_notify_conduit_error ((gchar*)pilot_id,
+				    conduit,
+				    message);
 }
 
 /* This toggles the callbacks for signal. Call with set=TRUE to 
@@ -206,17 +228,12 @@ set_callbacks (gboolean set, GnomePilotConduit *conduit, gchar *pilot_name)
 		if (progress_h != 0) g_warning ("Internal inconsistency, see %s:%d",
 					       __FILE__,__LINE__);
 		
-		progress_h = gtk_signal_connect (GTK_OBJECT (conduit),
-						 GNOME_PILOT_CONDUIT_SIGNAL_PROGRESS (conduit_progress_callback),
-						 pilot_name);
-		
-		error_h = gtk_signal_connect (GTK_OBJECT (conduit),
-					      GNOME_PILOT_CONDUIT_SIGNAL_ERROR (conduit_error_callback),
-					      pilot_name);
-		
-		message_h = gtk_signal_connect (GTK_OBJECT (conduit),
-					       GNOME_PILOT_CONDUIT_SIGNAL_MESSAGE (conduit_message_callback),
-					       pilot_name);	       
+		progress_h = gnome_pilot_conduit_connect__progress (conduit, conduit_progress_callback,
+								    pilot_name);
+		error_h = gnome_pilot_conduit_connect__error  (conduit, conduit_error_callback,
+							       pilot_name);
+		message_h = gnome_pilot_conduit_connect__message (conduit, conduit_message_callback,
+								  pilot_name);
 	} else {
 		if (progress_h == 0) {
 			/* We should never have set==FALSE but no progress_h(andler)
@@ -237,10 +254,13 @@ set_callbacks (gboolean set, GnomePilotConduit *conduit, gchar *pilot_name)
 
 /**************************************************************************/
 
+/* Carrier structure for backup conduits restore callback */
+
 static void
 backup_foreach (GnomePilotConduitBackup *conduit, GnomePilotDBInfo *info)
 {
-
+	int result;
+	
 	if (GNOME_IS_PILOT_CONDUIT_BACKUP (conduit) == FALSE) {
 		g_error (_("non-backup conduit in backup conduit list"));
 		return;
@@ -248,9 +268,14 @@ backup_foreach (GnomePilotConduitBackup *conduit, GnomePilotDBInfo *info)
 	g_assert (info != NULL);
 	
 	set_callbacks (TRUE, GNOME_PILOT_CONDUIT (conduit), info->pilotInfo->name);
-	if (gnome_pilot_conduit_backup_backup (conduit, info) == 0) {
+	result = gnome_pilot_conduit_backup_backup (conduit, info);	
+	if (result == 0) {
 		gpilot_add_log_entry (info->pilot_socket, _("%s backed up\n"), PI_DBINFO (info)->name);
-	} 
+	} else if (result < 0) {
+		gpilot_add_log_entry (info->pilot_socket, _("%s backup failed\n"), PI_DBINFO (info)->name);
+	} else if (result > 0) {
+		/* db not modified, not backup up */
+	}
 	set_callbacks (FALSE, GNOME_PILOT_CONDUIT (conduit), info->pilotInfo->name);
 }
 
@@ -301,16 +326,21 @@ iterate_dbs (gint pfd,
 		}
 
 		db_list = g_slist_append (db_list, g_strdup (PI_DBINFO (dbinfo)->name));
-                /*
-		g_message ("DB: %20s: Exclude=%3s, Backup=%3s Flags=0x%8.8x Creator=0x%lx Backupdate = %ld modifydate = %ld",
-			  PI_DBINFO (&dbinfo)->name,
-			  (PI_DBINFO (&dbinfo)->miscFlags & dlpDBMiscFlagExcludeFromSync)?"yes":"no",
-			  (PI_DBINFO (&dbinfo)->flags & dlpDBFlagBackup)?"yes":"no",
-			  PI_DBINFO (&dbinfo)->flags,
-			  PI_DBINFO (&dbinfo)->creator,
-			  PI_DBINFO (&dbinfo)->backupDate,
-			  PI_DBINFO (&dbinfo)->modifyDate);
-		*/
+
+		if (0) {
+			char creat[4];
+			memcpy (creat, (void*)&PI_DBINFO (dbinfo)->creator, 4);
+			g_message ("DB: %20s: Exclude=%3s, Backup=%3s Flags=0x%8.8x Creator=0x%lx (%c%c%c%c) Backupdate = %ld modifydate = %ld, %d/%d",
+				   PI_DBINFO (dbinfo)->name,
+				   (PI_DBINFO (dbinfo)->miscFlags & dlpDBMiscFlagExcludeFromSync)?"yes":"no",
+				   (PI_DBINFO (dbinfo)->flags & dlpDBFlagBackup)?"yes":"no",
+				   PI_DBINFO (dbinfo)->flags,
+				   PI_DBINFO (dbinfo)->creator, creat[3], creat[2], creat[1], creat[0],
+				   PI_DBINFO (dbinfo)->backupDate,
+				   PI_DBINFO (dbinfo)->modifyDate,
+				   index, g_list_length (dbs));
+		}
+
 		/* check if the base is marked as being excluded from sync */
 		if (!(PI_DBINFO (dbinfo)->miscFlags & dlpDBMiscFlagExcludeFromSync)) {
 			dbinfo->pu = pu;
@@ -320,12 +350,6 @@ iterate_dbs (gint pfd,
 
 			conduit = find_matching_conduit (conlist, dbinfo);
 
-			orbed_notify_overall_progress (pilot_info->name, index, g_list_length (dbs)); 
-
-			g_list_foreach (bconlist,
-					(GFunc) backup_foreach,
-					dbinfo);
-
 			if (conduit) {
 				/* Now call the iter method on the conduit, after setting up
 				   the signals. The signals aren't set before, since we 
@@ -335,8 +359,20 @@ iterate_dbs (gint pfd,
 				error = iter (GNOME_PILOT_CONDUIT_STANDARD (conduit), dbinfo);
 				set_callbacks (FALSE, GNOME_PILOT_CONDUIT (conduit), pilot_info->name);
 			}
+
+			orbed_notify_overall_progress (pilot_info->name, index, g_list_length (dbs)); 
+
+			/*
+			  It seems pretty erratic which has this and which hasn't,
+			  so I'm not doing this check.
+			if (PI_DBINFO (dbinfo)->miscFlags & dlpDBFlagBackup)
+			*/
+				g_list_foreach (bconlist,
+						(GFunc) backup_foreach,
+						dbinfo);
+
 		} else {
-			LOG ("Base %s is to be ignored by sync", PI_DBINFO (dbinfo)->name);
+			LOG (("Base %s is to be ignored by sync", PI_DBINFO (dbinfo)->name));
 			continue;
 		}
 		g_free (dbinfo); 
@@ -469,9 +505,8 @@ conduit_sync_default (GnomePilotConduitStandard *conduit, GnomePilotDBInfo *dbin
 	manager = gtk_object_get_data (GTK_OBJECT (conduit), GPCM_LABEL);
 	g_return_val_if_fail (conduit_config!=NULL,-1);
 	if (conduit_config->first_sync_type != GnomePilotConduitSyncTypeNotSet) {
-		char *conduit_name = gnome_pilot_conduit_management_get_name (manager);
+		const char *conduit_name = gnome_pilot_conduit_management_get_name (manager);
 		g_message (_("Conduit %s's first synchronization..."), conduit_name);
-		g_free (conduit_name);
 
 		gnome_pilot_conduit_config_remove_first_sync (conduit_config);
 		action = conduit_config->first_sync_type;
@@ -504,28 +539,19 @@ conduit_sync_default (GnomePilotConduitStandard *conduit, GnomePilotDBInfo *dbin
 static void
 install_db_foreach (GPilotRequest *req, GnomePilotInstallCarrier *carrier) {
 	gchar *pilot_name;
+	int err;
 
 	pilot_name = pilot_name_from_id (carrier->pu->userID, carrier->context);
 	set_callbacks (TRUE, carrier->conduit, pilot_name);
-	switch (req->type) {
-	case GREQ_INSTALL:
-		gnome_pilot_conduit_file_install_db (GNOME_PILOT_CONDUIT_FILE (carrier->conduit),
-						     carrier->pilot_socket,
-						     req->parameters.install.filename);
-		break;
-	case GREQ_RESTORE:
-		gnome_pilot_conduit_backup_restore (GNOME_PILOT_CONDUIT_BACKUP (carrier->conduit),
-						    carrier->pilot_socket,
-						    req->parameters.restore.directory);
-		break;
-	default:
-		g_warning (_("%s this request.type == %d is not a install/restore"), __PRETTY_FUNCTION__, req->type);
-		break;
-	}
+	err = gnome_pilot_conduit_file_install_db (GNOME_PILOT_CONDUIT_FILE (carrier->conduit),
+						   carrier->pilot_socket,
+						   req->parameters.install.filename,
+						   TRUE);
 	set_callbacks (FALSE, carrier->conduit, pilot_name);
+
 	g_free (pilot_name);
 	orbed_notify_completion (&req);
-};
+}
 
 static void
 install_foreach (GnomePilotConduit *conduit,
@@ -558,13 +584,27 @@ do_restore_foreach (GPilotRequest *req, GnomePilotInstallCarrier *carrier)
 	  throw an exception or something.  */
 	iterator = carrier->conduit_list;
 	while ( iterator != NULL ) {
-		GnomePilotConduitBackup *conduit;
-		conduit = GNOME_PILOT_CONDUIT_BACKUP (iterator->data);
-		set_callbacks (TRUE, GNOME_PILOT_CONDUIT (conduit), pilot_name);
-		gnome_pilot_conduit_backup_restore (conduit, carrier->pilot_socket,
-						    req->parameters.restore.directory);
-		iterator = iterator->next;
-		set_callbacks (FALSE, GNOME_PILOT_CONDUIT (conduit), pilot_name);
+		GList *iterator_two = carrier->file_conduit_list;
+		GnomePilotConduitBackup *backup_conduit = GNOME_PILOT_CONDUIT_BACKUP (iterator->data);
+		
+		while (iterator_two) {
+			GnomePilotBackupFuncCarrier backup_carrier;
+			GnomePilotConduitFile *file_conduit = GNOME_PILOT_CONDUIT_FILE (iterator_two->data);
+			backup_carrier.carrier = carrier;
+			backup_carrier.file_conduit = file_conduit;
+			backup_carrier.pilot_name = pilot_name;
+
+			set_callbacks (TRUE, GNOME_PILOT_CONDUIT (file_conduit), pilot_name);
+			gnome_pilot_conduit_backup_restore (backup_conduit, 
+							    carrier->pilot_socket,
+							    req->parameters.restore.directory,
+							    (GnomePilotConduitBackupRestore)gnome_pilot_conduit_backup_func,
+							    &backup_carrier);
+			set_callbacks (FALSE, GNOME_PILOT_CONDUIT (file_conduit), pilot_name);
+			
+			iterator_two = g_list_next (iterator_two);
+		}
+		iterator = g_list_next (iterator);
 	}
 
 	g_free (pilot_name);
@@ -572,8 +612,8 @@ do_restore_foreach (GPilotRequest *req, GnomePilotInstallCarrier *carrier)
 }
 
 static void
-unload_foreach (GnomePilotConduit *conduit,
-	       gpointer unused)
+gpilot_unload_conduit_foreach (GnomePilotConduit *conduit,
+			       gpointer unused)
 {
 	GnomePilotConduitManagement *manager;
 	g_return_if_fail (conduit != NULL);
@@ -639,7 +679,7 @@ gpilot_load_conduits (GPilotContext *context,
 		}
 		
 		gtk_object_set (GTK_OBJECT (conduit),
-				GNOME_PILOT_CONDUIT_ARG_PROGRESS_STEPPING (context->progress_stepping),
+				GNOME_PILOT_CONDUIT_PROP_PROGRESS_STEPPING (context->progress_stepping),
 				NULL);
 		gtk_object_set_data (GTK_OBJECT (conduit), GPCM_LABEL, manager);
 		gtk_object_set_data (GTK_OBJECT (conduit), GPCC_LABEL, conduit_config);
@@ -659,15 +699,79 @@ gpilot_load_conduits (GPilotContext *context,
 		g_free (conduit_name[i]);
 	}
 	g_free (conduit_name);
+	g_message ("Instantiated %d backup conduits, %d file conduits, %d other conduits",
+		   g_list_length (*blist), g_list_length (*flist), g_list_length (*clist));
 }
 
 void
 gpilot_unload_conduits (GList *list)
 {
-	g_list_foreach (list, (GFunc) unload_foreach, NULL);
+	g_list_foreach (list, (GFunc) gpilot_unload_conduit_foreach, NULL);
 	g_list_free (list);
 }
 
+/* 
+ * Start restoring a pilot profile, using the given (open hopefully)
+ * filedescriptor, given a device (in case we need it again) and the
+ * pilot info structure
+ */
+
+gboolean
+gpilot_start_unknown_restore (int pfd, 
+			      GPilotDevice *device,
+			      GPilotPilot *pilot)
+{
+	GnomePilotConduitManagement *gpcmb, *gpcmf;
+	GnomePilotConduit *b_conduit, *f_conduit;
+	int err1, err2;
+	gboolean result = TRUE;
+
+	gpcmb = gnome_pilot_conduit_management_new ("gpbackup1", GNOME_PILOT_CONDUIT_MGMT_ID);
+	gpcmf = gnome_pilot_conduit_management_new ("gpfile1", GNOME_PILOT_CONDUIT_MGMT_ID);
+	err1 = gnome_pilot_conduit_management_instantiate_conduit (gpcmb,
+								   pilot,
+								   &b_conduit);
+	err2 = gnome_pilot_conduit_management_instantiate_conduit (gpcmf,
+								   pilot,
+								   &f_conduit);
+		
+	if (err1 == GNOME_PILOT_CONDUIT_MGMT_OK && 
+	    err2 == GNOME_PILOT_CONDUIT_MGMT_OK &&
+	    GNOME_IS_PILOT_CONDUIT_BACKUP (b_conduit) &&
+	    GNOME_IS_PILOT_CONDUIT_FILE (f_conduit)) {
+		GnomePilotBackupFuncCarrier backup_carrier;
+		backup_carrier.carrier = g_new0 (GnomePilotInstallCarrier, 1);
+		backup_carrier.carrier->pilot_socket = pfd;
+		backup_carrier.pilot_name = pilot->name;
+		backup_carrier.file_conduit = GNOME_PILOT_CONDUIT_FILE (f_conduit);
+
+		set_callbacks (TRUE, GNOME_PILOT_CONDUIT (f_conduit), pilot->name);
+		gnome_pilot_conduit_backup_restore (GNOME_PILOT_CONDUIT_BACKUP (b_conduit),
+						    pfd, 
+						    NULL,
+						    (GnomePilotConduitBackupRestore)gnome_pilot_conduit_backup_func,
+						    &backup_carrier);
+		set_callbacks (FALSE, GNOME_PILOT_CONDUIT (f_conduit), pilot->name);
+
+		g_free (backup_carrier.carrier);
+	} else {
+		result = FALSE;
+	}
+	
+	if (result) {
+		struct PilotUser pu;
+		char *tmp;
+		tmp = g_strdup_printf (_("Setting user/id to %d/%s..."), pilot->pilot_id, pilot->pilot_username);
+		orbed_notify_daemon_message (pilot->name, NULL, tmp);
+		g_snprintf (pu.username, 127, "%s", pilot->pilot_username);
+		pu.userID = pilot->pilot_id;
+		dlp_WriteUserInfo (pfd, &pu);
+		g_free (tmp);
+	}
+							    
+	return result;
+}
+
 static void 
 run_conduit_sync_foreach (GPilotRequest *req,
 			 GnomePilotInstallCarrier *carrier)
@@ -676,7 +780,6 @@ run_conduit_sync_foreach (GPilotRequest *req,
 	GList *clist,*blist,*flist;
 	int err;
 
-	g_return_if_fail (conduit!=NULL);
 	g_return_if_fail (carrier!=NULL);
 
 	err = 0;
@@ -686,12 +789,12 @@ run_conduit_sync_foreach (GPilotRequest *req,
 	conduit = NULL;
 
 	conduit = find_matching_conduit_name (carrier->conduit_list,
-					     req->parameters.conduit.name);
+					      req->parameters.conduit.name);
 	if (conduit==NULL) {
 		/* FIXME: remove the bloody request, or the user will get this
 		   message every time */
-		g_error (_("Conduit %s requested, but not found"),
-			req->parameters.conduit.name);
+		g_warning (_("Conduit %s requested, but not found"),
+			   req->parameters.conduit.name);
 	} else {
 		if (GNOME_IS_PILOT_CONDUIT_BACKUP (conduit)) {
 			blist = g_list_append (blist, conduit);
@@ -705,16 +808,15 @@ run_conduit_sync_foreach (GPilotRequest *req,
 		}
 
 		if (flist) {
-			g_list_foreach (flist,(GFunc)install_foreach,&carrier);
+			g_list_foreach (flist, (GFunc)install_foreach, carrier);
 		} else {
-	    
 			err= iterate_dbs (carrier->pilot_socket,
-					 carrier->syncstamp,
-					 carrier->pu,
-					 clist,
-					 blist,
-					 conduit_sync_default,
-					 carrier->context); 
+					  carrier->syncstamp,
+					  carrier->pu,
+					  clist,
+					  blist,
+					  conduit_sync_default,
+					  carrier->context); 
 		}
 	}
 	orbed_notify_completion (&req);
@@ -750,6 +852,7 @@ gboolean gpilot_initial_synchronize_operations (int pilot_socket,
 	if (g_list_length (request_list)) {
 		do_normal_sync_stuff = FALSE;
 		carrier.conduit_list = g_list_copy (backup_conduit_list);
+		carrier.file_conduit_list = g_list_copy (file_conduit_list);
 		g_list_foreach (request_list,(GFunc)do_restore_foreach,&carrier);
 	}
 
@@ -759,11 +862,12 @@ gboolean gpilot_initial_synchronize_operations (int pilot_socket,
 	g_message ("Pilot has %d entries in conduit queue", g_list_length (request_list));
 	if (g_list_length (request_list)) {
 		carrier.conduit_list = g_list_copy (conduit_list);
-		carrier.conduit_list = g_list_concat (carrier.conduit_list, backup_conduit_list);
-		carrier.conduit_list = g_list_concat (carrier.conduit_list, file_conduit_list);
+		carrier.conduit_list = g_list_concat (carrier.conduit_list, g_list_copy (backup_conduit_list));
+		carrier.conduit_list = g_list_concat (carrier.conduit_list, g_list_copy (file_conduit_list));
 		do_normal_sync_stuff = FALSE;
 		g_list_foreach (request_list,(GFunc)run_conduit_sync_foreach,&carrier);
 		g_list_free (carrier.conduit_list);
+
 	}
 
 	return do_normal_sync_stuff;
@@ -786,15 +890,17 @@ gpilot_synchronize (int pilot_socket,
 	carrier.context = context;
 
 	/* now run through all the file install requests */
-	g_list_foreach (file_conduit_list,(GFunc)install_foreach,&carrier);
+	g_list_foreach (file_conduit_list, (GFunc)install_foreach, &carrier);
+
 	/* and then iterate over all conduits */
 	error = iterate_dbs (pilot_socket,
-			    stamp,
-			    pu,
-			    conduit_list,
-			    backup_conduit_list,
-			    conduit_synchronize,
-			    context);
+			     stamp,
+			     pu,
+			     conduit_list,
+			     backup_conduit_list,
+			     conduit_synchronize,
+			     context);
+
 	/* FIXME: empty queue for pilot here */
 
 	return error;
@@ -816,13 +922,13 @@ gpilot_copy_to_pilot (int pilot_socket,
 	carrier.pilot_socket = pilot_socket;
 	carrier.context = context;
 
-	g_list_foreach (file_conduit_list,(GFunc)install_foreach,&carrier);
-
+	g_list_foreach (file_conduit_list, (GFunc)install_foreach, &carrier);
+	
 	error = iterate_dbs (pilot_socket, stamp, pu,
-			    conduit_list,
-			    backup_conduit_list,
-			    conduit_copy_to_pilot,
-			    context);
+			     conduit_list,
+			     backup_conduit_list,
+			     conduit_copy_to_pilot,
+			     context);
 	return error;
 }
 
@@ -859,13 +965,13 @@ gpilot_merge_to_pilot (int pilot_socket,
 	carrier.pilot_socket = pilot_socket;
 	carrier.context = context;
 
-	g_list_foreach (file_conduit_list,(GFunc)install_foreach,&carrier);
+	g_list_foreach (file_conduit_list, (GFunc)install_foreach, &carrier);
 
 	error = iterate_dbs (pilot_socket, stamp, pu,
-			    conduit_list,
-			    backup_conduit_list,
-			    conduit_merge_to_pilot,
-			    context);
+			     conduit_list,
+			     backup_conduit_list,
+			     conduit_merge_to_pilot,
+			     context);
 
 	return error;
 }
@@ -898,10 +1004,15 @@ gpilot_sync_default (int pilot_socket, GnomePilotSyncStamp *stamp,
 	carrier.pu = pu;
 	carrier.pilot_socket = pilot_socket;
 	carrier.context = context;
-	g_list_foreach (file_conduit_list,(GFunc)install_foreach,&carrier);
+	g_list_foreach (file_conduit_list, (GFunc)install_foreach, &carrier);
 
-	error=iterate_dbs (pilot_socket, stamp, pu, conduit_list, backup_conduit_list,
-			  conduit_sync_default, context);
+	error=iterate_dbs (pilot_socket, 
+			   stamp, 
+			   pu, 
+			   conduit_list, 
+			   backup_conduit_list,
+			   conduit_sync_default, 
+			   context);
 	return error;
 }
 
