@@ -34,15 +34,15 @@ int main(int argc,char *argv[]) {
   char salt[3];
 
   if (argc < 2) {
-    fprintf(stderr,"usage:%s %s\n",argv[0],TTYPrompt);
+    fprintf(stderr,"usage:%s\n",argv[0]);
     exit(2);
   }
-  if (!(sd = pi_socket(PI_AF_SLP, PI_SOCK_STREAM, PI_PF_PADP))) {
+  if (!(sd = pi_socket(PI_AF_PILOT, PI_SOCK_STREAM, PI_PF_PADP))) {
     perror("pi_socket");
     exit(1);
   }
     
-  addr.pi_family = PI_AF_SLP;
+  addr.pi_family = PI_AF_PILOT;
   strcpy(addr.pi_device,argv[1]);
   
   ret = pi_bind(sd, (struct sockaddr*)&addr, sizeof(addr));
